@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -34,9 +34,7 @@ SieveGlobalVariableActionWidget::SieveGlobalVariableActionWidget(QWidget *parent
     initWidget();
 }
 
-SieveGlobalVariableActionWidget::~SieveGlobalVariableActionWidget()
-{
-}
+SieveGlobalVariableActionWidget::~SieveGlobalVariableActionWidget() = default;
 
 void SieveGlobalVariableActionWidget::generatedScript(QString &script)
 {
@@ -122,11 +120,20 @@ void SieveGlobalVariableActionWidget::setVariableValue(const QString &name)
 void SieveGlobalVariableActionWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             mVariableName->setText(element.readElementText());
         } else {
-            error += i18n("Unknown tag \"%1\" during loading of variables.", *tagName.string()) + QLatin1Char('\n');
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            const QString result = *tagName.string();
+#else
+            const QString result = tagName.toString();
+#endif
+            error += i18n("Unknown tag \"%1\" during loading of variables.", result) + QLatin1Char('\n');
             qCDebug(LIBKSIEVE_LOG) << " SieveGlobalVariableActionWidget::loadScript unknown tagName " << tagName;
         }
     }
@@ -164,9 +171,7 @@ SieveGlobalVariableWidget::SieveGlobalVariableWidget(QWidget *parent)
     setPageType(KSieveUi::SieveScriptBlockWidget::GlobalVariable);
 }
 
-SieveGlobalVariableWidget::~SieveGlobalVariableWidget()
-{
-}
+SieveGlobalVariableWidget::~SieveGlobalVariableWidget() = default;
 
 void SieveGlobalVariableWidget::slotHelp()
 {
@@ -207,9 +212,7 @@ SieveGlobalVariableLister::SieveGlobalVariableLister(QWidget *parent)
     updateAddRemoveButton();
 }
 
-SieveGlobalVariableLister::~SieveGlobalVariableLister()
-{
-}
+SieveGlobalVariableLister::~SieveGlobalVariableLister() = default;
 
 void SieveGlobalVariableLister::slotAddWidget(QWidget *w)
 {
@@ -299,7 +302,11 @@ SieveGlobalVariableActionWidget::VariableElement SieveGlobalVariableLister::load
     QString variableValue;
     int index = 0;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             if (index == 0) {
                 variableName = element.readElementText();
